@@ -11,7 +11,7 @@ use Readonly;
 
 use JSON;
 
-our $VERSION = 0.25;
+our $VERSION = 0.26;
 
 Readonly::Scalar our $ATTRIBUTE_METACLASS_TO_SKIP => q[MooseX::Getopt::Meta::Attribute::NoGetopt];
 
@@ -156,7 +156,7 @@ sub attributes_as_command_options {
 
     if (ref $attributes->{$key} eq q{HASH}) {
 
-      foreach my $h_key (keys %{$attributes->{$key}}) {
+      foreach my $h_key (sort {$a cmp $b} keys %{$attributes->{$key}}) {
 
         if (defined $attributes->{$key}->{$h_key} && ! ref $attributes->{$key}->{$h_key}) { # don't pass through empty strings or references
           my $string = $self->_create_string($key, qq{$h_key=$attributes->{$key}->{$h_key}}, $arg_refs, 1);
@@ -276,6 +276,7 @@ sub _hash_of_attribute_values {
 
     # if lazy_build, then will only propagate data if it is built, saving any expensive build routines.
     # obviously, this has the effect that you may need to do it twice, or force a build before the cloning of data
+    # NOTE: this doesn't account for those which are lazy, and have a builder, but no predicate (generated by lazy_build flag only)
     if ($attr->{predicate}) {
       my $pred = $attr->{predicate};
       next if !$self->$pred();
